@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# $Id: utils.py 146688 2010-10-21 16:06:59Z glenfant $
+# $Id: utils.py 228249 2010-12-05 01:02:42Z glenfant $
 """Misc utilities"""
 
 from Products.Five import BrowserView
@@ -15,11 +15,12 @@ class Utils(BrowserView):
         if CONTROLPANEL_ID not in zcp.objectIds():
             mpcp = ControlPanel()
             zcp._setObject(CONTROLPANEL_ID, mpcp)
-        return u"Monkey pacher panel added. Click the \"Back\" button."
+        return u"Monkey pacher panel added. Click the \"Back\" button of your browser."
 
     def remove(self):
         """Removes the control panel
         """
         zcp = self.context.Control_Panel
-        zcp._delObject(CONTROLPANEL_ID)
-        return u"Monkey pacher panel removed. Click the \"Back\" button."
\ No newline at end of file
+        if CONTROLPANEL_ID not in zcp.objectIds():
+            zcp._delObject(CONTROLPANEL_ID)
+        return u"Monkey pacher panel removed. Click the \"Back\" button of your browser."
